##  KPI Status
KPIs compare the current period with a selected past period and are calculated daily, offering a daily snapshot of workspace metrics. By default, data compares to the last quarter, but you can choose a different period from the **Compare to** list in the upper-left corner. Comparing current data with past results provides a historical perspective, enabling you to:
  * Understand how your metrics evolve over time and identify long-term trends or changes.
  * Benchmark current performance against historical data.
  * Assess the impact of changes and initiatives on your IT landscape.


The KPI card displays percentage points (pp) to indicate how the KPI changes compared to the last day of the selected period, expressed as a percentage. The color-coding on the KPI card reflects the comparison to a past period:
  * **Green** : improving
  * **Red** : declining
  * **Grey** : no changes
  * **No color-coding** : comparison is not meaningful


For example, the KPI "Technical fit of applications" in the image below decreased by 7.7% this quarter, dropping from 53.8% to 46.2%. The current metric is compared to the last day of the previous quarter. The color of the KPI card is red, indicating a decline in KPI performance.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioc9a6775f0ce04f4ebebe7f307a00f522_LowRes.png)
KPI Status Showing How Data is Compared to a Selected Period
